@@ -84,7 +84,7 @@ FileNameSearchProtocol::FileNameSearchProtocol(const QByteArray &pool, const QBy
     : QObject()
     , WorkerBase("search", pool, app)
 {
-    QDBusInterface kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded5"));
+    QDBusInterface kded(QStringLiteral("org.kde.kded6"), QStringLiteral("/kded"), QStringLiteral("org.kde.kded6"));
     kded.call(QStringLiteral("loadModule"), QStringLiteral("filenamesearchmodule"));
 }
 
@@ -169,7 +169,7 @@ void FileNameSearchProtocol::searchDir(const QUrl &dirUrl,
                                        std::set<QString> &iteratedDirs,
                                        std::queue<QUrl> &pendingDirs)
 {
-    KIO::ListJob *listJob = KIO::listRecursive(dirUrl, KIO::HideProgressInfo, false /* hidden */);
+    KIO::ListJob *listJob = KIO::listRecursive(dirUrl, KIO::HideProgressInfo, KIO::ListJob::ListFlags{});
 
     connect(this, &QObject::destroyed, listJob, [listJob]() {
         listJob->kill();
