@@ -1,4 +1,4 @@
-/* Copytester is a test case for the fish kioslave. It copies 100 files from /tmp to /tmp/test using fish's functions.
+/* Copytester is a test case for the fish KIO worker. It copies 100 files from /tmp to /tmp/test using fish's functions.
 It was written to verify KDE bug 147948: https://bugs.kde.org/show_bug.cgi?id=147948
 
 To use this program, do
@@ -7,13 +7,14 @@ To use this program, do
 */
 
 #include <copytester.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <kio/copyjob.h>
-#include <kapplication.h>
 
 class TransferJob;
 
-Browser::Browser() : QWidget(NULL)
+Browser::Browser()
+    : QWidget(NULL)
 {
     slotButtonClicked();
 }
@@ -21,25 +22,24 @@ Browser::Browser() : QWidget(NULL)
 void Browser::slotButtonClicked()
 {
     kDebug() << "entering function";
-    // creating a kioslave
+    // creating a KIO worker
     kDebug() << "getting via fish*************************************************************";
     KUrl::List selectedUrls;
 
-    for (int i=1; i<=99; i++)
-    {
-        QString filename=QString("/tmp/fishtest");
+    for (int i = 1; i <= 99; i++) {
+        QString filename = QString("/tmp/fishtest");
         filename.append(QString::number(i)).append(".txt");
         kDebug() << filename;
         selectedUrls.push_back(KUrl(filename));
     }
     KUrl destUrl("fish://root@localhost/tmp/test");
-    KIO::CopyJob* job0 = KIO::copy( selectedUrls, destUrl );
+    KIO::CopyJob *job0 = KIO::copy(selectedUrls, destUrl);
     job0->start();
 }
 
-void Browser::dataishere(KIO::Job *,const QByteArray & data )
+void Browser::dataishere(KIO::Job *, const QByteArray &data)
 {
-    static int counter=0;
+    static int counter = 0;
     kDebug() << ++counter << " data is here*************************************************************";
     kDebug() << data;
     kapp->quit();
